@@ -86,7 +86,7 @@ class AutoDict(dict):
         :class:`AutoOrderedDict` - the ordered version
 
     References:
-        .. [1] http://stackoverflow.com/questions/651794/init-dict-of-dicts
+        .. [SO_651794] http://stackoverflow.com/questions/651794/init-dict-of-dicts
 
     Example:
         >>> import ubelt as ub
@@ -180,7 +180,7 @@ def dzip(items1, items2, cls=dict):
     if len(items1) == 0 and len(items2) == 1:
         # Corner case:
         # allow the first list to be empty and the second list to broadcast a
-        # value. This means that the equality check wont work for the case
+        # value. This means that the equality check won't work for the case
         # where items1 and items2 are supposed to correspond, but the length of
         # items2 is 1.
         items2 = []
@@ -323,6 +323,10 @@ def find_duplicates(items, k=2, key=None):
         dict[T, List[int]] :
             maps each duplicate item to the indices at which it appears
 
+    Notes:
+        Similar to :func:`more_itertools.duplicates_everseen`,
+        :func:`more_itertools.duplicates_justseen`.
+
     Example:
         >>> import ubelt as ub
         >>> items = [0, 0, 1, 2, 3, 3, 0, 12, 2, 9]
@@ -778,13 +782,14 @@ def named_product(_=None, **basis):
         the input keys instead of an tuple.
 
         This function used to be called "basis_product", but "named_product"
-        might be more appropriate. This function exists in other places ([1],
-        [2], and [3]).
+        might be more appropriate. This function exists in other places
+        ([minstrel271_namedproduct]_, [pytb_namedproduct]_, and
+        [Hettinger_namedproduct]_).
 
     References:
-        .. [1] https://gist.github.com/minstrel271/d51654af3fa4e6411267
-        .. [2] https://py-toolbox.readthedocs.io/en/latest/modules/itertools.html#
-        .. [3] https://twitter.com/raymondh/status/970380630822305792
+        .. [minstrel271_namedproduct] https://gist.github.com/minstrel271/d51654af3fa4e6411267
+        .. [pytb_namedproduct] https://py-toolbox.readthedocs.io/en/latest/modules/itertools.html#
+        .. [Hettinger_namedproduct] https://twitter.com/raymondh/status/970380630822305792
 
     Example:
         >>> # An example use case is looping over all possible settings in a
@@ -845,9 +850,9 @@ def varied_values(longform, min_variations=0, default=NoParam):
     Given a list of dictionaries, find the values that differ between them.
 
     Args:
-        longform (List[Dict]):
-            This is longform data, as described in [1]_. It is a list of
-            dictionaries.
+        longform (List[Dict[KT, VT]]):
+            This is longform data, as described in [SeabornLongform]_. It is a
+            list of dictionaries.
 
             Each item in the list - or row - is a dictionary and can be thought
             of as an observation. The keys in each dictionary are the columns.
@@ -858,11 +863,12 @@ def varied_values(longform, min_variations=0, default=NoParam):
             "columns" with fewer than ``min_variations`` unique values are
             removed from the result.
 
-        default (object, default=NoParam):
+        default (VT, default=NoParam):
             if specified, unspecified columns are given this value.
 
     Returns:
-        dict : a mapping from each "column" to the set of unique values it took
+        Dict[KT, List[VT]] :
+            a mapping from each "column" to the set of unique values it took
             over each "row". If a column is not specified for each row, it is
             assumed to take a `default` value, if it is specified.
 
@@ -871,7 +877,7 @@ def varied_values(longform, min_variations=0, default=NoParam):
             do not contain the same columns.
 
     References:
-        .. [1] https://seaborn.pydata.org/tutorial/data_structure.html#long-form-data
+        .. [SeabornLongform] https://seaborn.pydata.org/tutorial/data_structure.html#long-form-data
 
     Example:
         >>> # An example use case is to determine what values of a
