@@ -16,6 +16,7 @@ if it needs to.
 """
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
+from ubelt.util_const import NoParam
 from os.path import basename, join, exists, dirname
 import os
 import sys
@@ -35,7 +36,8 @@ else:
 
 
 def download(url, fpath=None, dpath=None, fname=None, hash_prefix=None,
-             hasher='sha512', chunksize=8192, verbose=1, progkw=None):
+             hasher='sha512', chunksize=8192, verbose=1, timeout=NoParam,
+             progkw=None):
     """
     Downloads a url to a file on disk.
 
@@ -76,6 +78,12 @@ def download(url, fpath=None, dpath=None, fname=None, hash_prefix=None,
         verbose (int, default=1):
             Verbosity level 0 or 1.
 
+        timeout (float, default=NoParam):
+            Specify timeout in seconds for :func:`urllib.request.urlopen`.  (if
+            not specified, the global default timeout setting will be used)
+            This only works for HTTP, HTTPS and FTP connections for blocking
+            operations like the connection attempt.
+
         progkw (Dict | None):
             if specified provides extra arguments to the progress iterator
 
@@ -87,14 +95,15 @@ def download(url, fpath=None, dpath=None, fname=None, hash_prefix=None,
         RuntimeError - if the hash does not match the hash_prefix
 
     Note:
-        Based largely on code in pytorch [4]_ with modifications influenced by
-        other resources [1]_ [2]_ [3]_.
+        Based largely on code in pytorch [TorchDL]_ with modifications
+        influenced by other resources [Shichao_2012]_ [SO_15644964]_
+        [SO_16694907]_.
 
     References:
-        .. [1] http://blog.moleculea.com/2012/10/04/urlretrieve-progres-indicator/
-        .. [2] http://stackoverflow.com/questions/15644964/python-progress-bar-and-downloads
-        .. [3] http://stackoverflow.com/questions/16694907/how-to-download-large-file-in-python-with-requests-py
-        .. [4] https://github.com/pytorch/pytorch/blob/2787f1d8edbd4aadd4a8680d204341a1d7112e2d/torch/hub.py#L347
+        .. [Shichao_2012] https://blog.shichao.io/2012/10/04/progress_speed_indicator_for_urlretrieve_in_python.html
+        .. [SO_15644964] http://stackoverflow.com/questions/15644964/python-progress-bar-and-downloads
+        .. [SO_16694907] http://stackoverflow.com/questions/16694907/how-to-download-large-file-in-python-with-requests-py
+        .. [TorchDL] https://github.com/pytorch/pytorch/blob/2787f1d8edbd4aadd4a8680d204341a1d7112e2d/torch/hub.py#L347
 
     Example:
         >>> # xdoctest: +REQUIRES(--network)
@@ -141,6 +150,10 @@ def download(url, fpath=None, dpath=None, fname=None, hash_prefix=None,
     import tempfile
     import hashlib
 
+    if timeout is NoParam:
+        import socket
+        timeout = socket._GLOBAL_DEFAULT_TIMEOUT
+
     if PY2:  # nocover
         from urllib2 import urlopen  # NOQA
     else:
@@ -168,7 +181,9 @@ def download(url, fpath=None, dpath=None, fname=None, hash_prefix=None,
             print('Downloading url={!r} to fpath={!r}'.format(
                 url, fpath))
 
-    urldata = urlopen(url)
+    # TODO: might want to open the url with different args
+    urldata = urlopen(url, timeout=timeout)
+
     meta = urldata.info()
     try:
         if hasattr(meta, 'getheaders'):  # nocover
@@ -423,7 +438,7 @@ def _check_hash_stamp(fpath, hash_prefix, hasher, verbose, needs_download=False)
                     hash_prefix, hashstr))
             needs_download = True
     elif exists(fpath):
-        # If the file exists, but the hash doesnt exist, simply compute the
+        # If the file exists, but the hash does not exist, simply compute the
         # hash of the existing file instead of redownloading it.
         # Redownload if this fails.
         from ubelt import util_hash
