@@ -17,7 +17,7 @@ the operating system.
 The :func:`ensuredir` function operates like ``mkdir -p`` in unix.
 
 The :class:`Path` object is an extension of :class:`pathlib.Path` that contains
-extra convinience methods corresponding to the extra functional methods in this
+extra convenience methods corresponding to the extra functional methods in this
 module.
 """
 from __future__ import absolute_import, division, print_function, unicode_literals
@@ -26,10 +26,16 @@ from os.path import (
 )
 import os
 import sys
-import pathlib
-
+from ubelt import util_io
 
 PY2 = sys.version_info[0] == 2
+PY_LE_35 = sys.version_info[0:2] <= (3, 5)
+
+if PY2:
+    # Use pathlib2 backport in Python2
+    import pathlib2 as pathlib
+else:
+    import pathlib
 
 
 __all__ = [
@@ -64,7 +70,7 @@ def augpath(path, suffix='', prefix='', ext=None, base=None, dpath=None,
 
         base (str | None, default=None):
             if specified, replaces the basename without extension.
-            Note: this is refered to as stem in :class:`ub.Path`.
+            Note: this is referred to as stem in :class:`ub.Path`.
 
         dpath (str | PathLike | None, default=None):
             if specified, replaces the specified "relative" directory, which by
@@ -219,7 +225,7 @@ def shrinkuser(path, home='~'):
             '%USERPROFILE%' instead.
 
     Returns:
-        str: path - shortened path replacing the home directory with a tilde
+        str: path - shortened path replacing the home directory with a symbol
 
     Example:
         >>> from ubelt.util_path import *  # NOQA
@@ -283,7 +289,7 @@ def ensuredir(dpath, mode=0o1777, verbose=0, recreate=False):
         str: path - the ensured directory
 
     SeeAlso:
-        :method:`ub.Path.ensuredir`
+        :func:`ubelt.Path.ensuredir`
 
     Note:
         This function is not thread-safe in Python2
@@ -378,9 +384,27 @@ _PathBase = pathlib.WindowsPath if os.name == 'nt' else pathlib.PosixPath
 
 class Path(_PathBase):
     """
-    An extension of :class:`pathlib.Path` with extra convinience methods
+    An extension of :class:`pathlib.Path` with extra convenience methods
     """
 
+    def touch(self, mode=0o666, exist_ok=True):
+        """
+        Create this file with the given access mode, if it doesn't exist.
+
+        Returns:
+            Path: returns itself
+
+        Notes:
+            The :func:`ubelt.util_io.touch` function currently has a slightly
+            different implementation. This uses whatever the pathlib version
+            is. This may change in the future.
+        """
+        # modify touch to return self
+        # Note: util_io.touch is more expressive than standard python
+        # touch, may want to use that instead.
+        super(Path, self).touch(mode=mode, exist_ok=exist_ok)
+        return self
+
     def ensuredir(self, mode=0o777):
         """
         Concise alias of ``self.mkdir(parents=True, exist_ok=True)``
@@ -408,8 +432,9 @@ class Path(_PathBase):
 
     def expandvars(self):
         """
-        As discussed in CPythonIssue21301_, CPython wont be adding expandvars
-        to pathlib. I think this is a mistake, so I added it in this extension.
+        As discussed in [CPythonIssue21301]_, CPython won't be adding
+        expandvars to pathlib. I think this is a mistake, so I added it in this
+        extension.
 
         Returns:
             Path: path with expanded environment variables
@@ -433,7 +458,6 @@ class Path(_PathBase):
             >>> #home_v1 = ub.Path('$HOME').expand()
             >>> home_v2 = ub.Path('~/').expand()
             >>> assert isinstance(home_v2, ub.Path)
-            >>> # xdoctest: +REQUIRES(PY3)
             >>> home_v3 = ub.Path.home()
             >>> #print('home_v1 = {!r}'.format(home_v1))
             >>> print('home_v2 = {!r}'.format(home_v2))
@@ -455,7 +479,7 @@ class Path(_PathBase):
                 '%USERPROFILE%' instead.
 
         Returns:
-            str: path - shortened path replacing the home directory with a tilde
+            Path: path - shortened path replacing the home directory with a symbol
 
         Example:
             >>> import ubelt as ub
@@ -525,3 +549,78 @@ class Path(_PathBase):
                           multidot=multidot)
         new = self.__class__(aug)
         return new
+
+    def delete(self):
+        """
+        Removes a file or recursively removes a directory.
+        If a path does not exist, then this is does nothing.
+
+        SeeAlso:
+            :func:`ubelt.delete`
+
+        Returns:
+            Path: reference to self
+
+        Example:
+            >>> import ubelt as ub
+            >>> from os.path import join
+            >>> base = ub.Path(ub.ensure_app_cache_dir('ubelt', 'delete_test2'))
+            >>> dpath1 = (base / 'dir').ensuredir()
+            >>> (base / 'dir' / 'subdir').ensuredir()
+            >>> (base / 'dir' / 'to_remove1.txt').touch()
+            >>> fpath1 = (base / 'dir' / 'subdir' / 'to_remove3.txt').touch()
+            >>> fpath2 = (base / 'dir' / 'subdir' / 'to_remove2.txt').touch()
+            >>> assert all(p.exists() for p in [dpath1, fpath1, fpath2])
+            >>> fpath1.delete()
+            >>> assert all(p.exists() for p in [dpath1, fpath2])
+            >>> assert not fpath1.exists()
+            >>> dpath1.delete()
+            >>> assert not any(p.exists() for p in [dpath1, fpath1, fpath2])
+        """
+        if PY_LE_35:  # nocover
+            util_io.delete(str(self))
+        else:
+            util_io.delete(self)
+        return self
+
+    def __fspath__(self):
+        # Only for 3.5. Remove after 3.5 support is removed.
+        return str(self)
+
+
+if PY_LE_35:  # nocover
+    def _fspath(path):
+        """
+        Return the file system path representation of the object.
+
+        If the object is str or bytes, then allow it to pass through as-is. If
+        the object defines __fspath__(), then return the result of that method.
+        All other types raise a TypeError.
+
+        Internal helper for cases where os.fspath does not exist on older Python
+        """
+        import six
+        string_types = six.string_types
+
+        if isinstance(path, string_types):
+            return path
+
+        # Work from the object's type to match method resolution of other magic
+        # methods.
+        path_type = type(path)
+        try:
+            path_repr = path_type.__fspath__(path)
+        except AttributeError:
+            if hasattr(path_type, '__fspath__'):
+                raise
+            else:
+                raise TypeError("expected str, bytes or os.PathLike object, "
+                                "not " + path_type.__name__)
+        if isinstance(path_repr, string_types):
+            return path_repr
+        else:
+            raise TypeError("expected {}.__fspath__() to return str or bytes, "
+                            "not {}".format(path_type.__name__,
+                                            type(path_repr).__name__))
+else:
+    _fspath = os.fspath
